<h1 align="center">Faciem</h1>
<p align="center">Face Detection model implementation in Tensorflow 2.0</p>

## Table of Contents

- [Introduction](#introduction)
  - [Installation](#installation)

# Introduction

This repository contains the implementation of the face detection models in Tensorflow 2.0.


## Installation

`pip install faciem`

